@@ -4,7 +4,7 @@ import abc
 class FlockAIController(metaclass=abc.ABCMeta):
 
     @abc.abstractmethod
-    def __init__(self, config):
+    def __init__(self):
         raise NotImplementedError
 
     @abc.abstractmethod
